@@ -1,5 +1,5 @@
 """
-CIS is an open source command-line tool for easy collocation, visualization, analysis, and
+CIS is an open source command-line tool and Python library for easy collocation, visualization, analysis, and
 comparison of diverse gridded and ungridded datasets used in the atmospheric sciences.
 
 .. note ::
@@ -7,12 +7,8 @@ comparison of diverse gridded and ungridded datasets used in the atmospheric sci
     The CIS documentation has detailed usage information, including a :doc:`user guide <../index>`
     for new users.
 
-As a commmand line tool, CIS has not been designed with a python API in mind. There are however some utility functions
-that may provide a useful start for those who wish to use CIS as a python library. The functions in this module provide
-the main way to load your data. They can be easily import using, for example: `from cis import read_data`.
-
 The :func:`read_data` function is a simple way to read a single gridded or ungridded data object (e.g. a NetCDF
-variable) from one or more files. CIS will determine the best way to interperet the datafile by comparing the file
+variable) from one or more files. CIS will determine the best way to interpret the datafile by comparing the file
 signature with the built-in data reading plugins and any user defined plugins. Specifying a particular ``product``
 allows the user to override this automatic detection.
 
@@ -21,11 +17,11 @@ more than one variable name. This function returns a list of data objects, eithe
 ungridded, but not a mix. For ungridded data lists it is assumed that all objects share the same coordinates.
 """
 __author__ = "David Michel, Daniel Wallis, Duncan Watson-Parris, Richard Wilkinson, Ian Bush, Matt Kendall, John Holt"
-__version__ = "1.4.0"
+__version__ = "1.5.0"
 __status__ = "Stable"
 __website__ = "http://www.cistools.net/"
 
-__all__ = ['read_data', 'read_data_list']
+__all__ = ['read_data', 'read_data_list', 'get_variables']
 
 
 def read_data(filenames, variable, product=None):
@@ -71,4 +67,28 @@ def read_data_list(filenames, variables, product=None, aliases=None):
         raise IOError(e)
     if len(file_set) == 0:
         raise IOError("No files found which match: {}".format(filenames))
-    return DataReader().read_data_list(expand_filelist(filenames), variables, product, aliases)
+    return DataReader().read_data_list(file_set, variables, product, aliases)
+
+
+def get_variables(filenames, product=None, type=None):
+    """
+    Get a list of variables names from a list of files. Files can be either gridded or ungridded but not a mix of both.
+
+    :param filenames:   The filenames of the files to read. This can be either a single filename as a string, a comma
+     separated list, or a :class:`list` of string filenames. Filenames can include directories which will be expanded to
+     include all files in that directory, or wildcards such as ``*`` or ``?``.
+    :type filenames: string or list
+    :param str product: The name of the data reading plugin to use to read the data (e.g. ``Cloud_CCI``).
+    :param str type: The type of HDF data to read, i.e. 'VD' or 'SD'
+    :return:  A list of the variables
+    """
+    from cis.data_io.data_reader import expand_filelist
+    from cis.data_io.products.AProduct import get_variables
+
+    try:
+        file_set = expand_filelist(filenames)
+    except ValueError as e:
+        raise IOError(e)
+    if len(file_set) == 0:
+        raise IOError("No files found which match: {}".format(filenames))
+    return get_variables(file_set, product=product, data_type=type)
