@@ -5,7 +5,7 @@ import logging
 from time import gmtime, strftime
 import numpy
 
-from cis import utils
+import six
 from cis.data_io.netcdf import get_data as netcdf_get_data
 from cis.data_io.hdf_vd import get_data as hdf_vd_get_data
 from cis.data_io.hdf_sd import get_data as hdf_sd_get_data
@@ -13,35 +13,61 @@ from cis.data_io.common_data import CommonData, CommonDataList
 from cis.data_io.hyperpoint_view import UngriddedHyperPointView
 from cis.data_io.write_netcdf import add_data_to_file, write_coordinates
 from cis.utils import listify
+import cis.maths
 
 
 class Metadata(object):
+
     @classmethod
     def from_CubeMetadata(cls, cube_meta):
         return cls(name=cube_meta.var_name, standard_name=cube_meta.standard_name, long_name=cube_meta.long_name,
                    units=str(cube_meta.units), misc=cube_meta.attributes)
 
-    def __init__(self, name='', standard_name='', long_name='', shape='', units='', range='', factor='', offset='',
-                 missing_value='', calendar='', history='', misc=None):
+    def __init__(self, name='', standard_name='', long_name='', shape=None, units='', range=None, factor=None,
+                 offset=None, missing_value=None, history='', misc=None):
         self._name = name
+
+        self._standard_name = ''
         if standard_name:
             self.standard_name = standard_name
         elif name:
             self.standard_name = Metadata.guess_standard_name(name)
+
         self.long_name = long_name
         self.shape = shape
+
         self.units = units
         self.range = range
         self.factor = factor
         self.offset = offset
         self.missing_value = missing_value
-        self.calendar = calendar
         self.history = history
         if misc is None:
             self.misc = {}
         else:
             self.misc = misc
 
+    def __eq__(self, other):
+        result = NotImplemented
+
+        if isinstance(other, Metadata):
+            result = self._name == other._name and \
+                     self._standard_name == other._standard_name and \
+                     self.long_name == other.long_name and \
+                     self.units == other.units
+        return result
+
+    # Must supply __ne__, Python does not defer to __eq__ for negative equality
+    def __ne__(self, other):
+        result = self.__eq__(other)
+        if result is not NotImplemented:
+            result = not result
+        return result
+
+    # Must supply __hash__, Python 3 does not enable it if __eq__ is defined
+    def __hash__(self):
+        return hash(id(self))
+
     def summary(self, offset=5):
         """
         Creates a unicode summary of the metadata object
@@ -49,58 +75,81 @@ class Metadata(object):
         :param offset: The left hand padding to apply to the text
         :return: The summary
         """
-        string = u''
-        string += u'{pad:{width}}Long name = {lname}\n'.format(pad=' ', width=offset, lname=self.long_name)
-        string += u'{pad:{width}}Standard name = {sname}\n'.format(pad=' ', width=offset, sname=self.standard_name)
-        string += u'{pad:{width}}Units = {units}\n'.format(pad=' ', width=offset, units=self.units)
-        if self.calendar:
-            string += u'{pad:{width}}Calendar = {cal}\n'.format(pad=' ', width=offset, cal=self.calendar)
-        string += u'{pad:{width}}Missing value = {mval}\n'.format(pad=' ', width=offset, mval=self.missing_value)
-        string += u'{pad:{width}}Range = {range}\n'.format(pad=' ', width=offset, range=self.range)
-        string += u'{pad:{width}}History = {history}\n'.format(pad=' ', width=offset, history=self.history)
+        from datetime import datetime
+        string = ''
+        string += '{pad:{width}}Long name = {lname}\n'.format(pad=' ', width=offset, lname=self.long_name)
+        string += '{pad:{width}}Standard name = {sname}\n'.format(pad=' ', width=offset, sname=self.standard_name)
+        string += '{pad:{width}}Units = {units}\n'.format(pad=' ', width=offset, units=self.units)
+        string += '{pad:{width}}Missing value = {mval}\n'.format(pad=' ', width=offset, mval=self.missing_value)
+        # str(tuple) returns repr(obj) on each item in the tuple, if we have a datetime tuple then we want str(obj)
+        #  instead. Just make that ourselves here instead (as a str to avoid the extra quotes if we make a 'real' tuple)
+        if isinstance(self.range[0], datetime):
+            range_tuple = '({}, {})'.format(*self.range)
+        else:
+            range_tuple = self.range
+        string += '{pad:{width}}Range = {range}\n'.format(pad=' ', width=offset, range=range_tuple)
+        string += '{pad:{width}}History = {history}\n'.format(pad=' ', width=offset, history=self.history)
         if self.misc:
-            string += u'{pad:{width}}Misc attributes: \n'.format(pad=' ', width=offset)
-            for k, v in self.misc.iteritems():
-                string += u'{pad:{width}}{att} = {val}\n'.format(pad=' ', width=offset + 2, att=k.title(), val=v)
+            string += '{pad:{width}}Misc attributes: \n'.format(pad=' ', width=offset)
+            for k, v in self.misc.items():
+                string += '{pad:{width}}{att} = {val}\n'.format(pad=' ', width=offset + 2, att=k.title(), val=v)
         return string
 
     def __str__(self):
-        return self.summary().encode(errors='replace')
+        # six has a decorator for this bit, but it doesn't do errors='replace'.
+        if six.PY3:
+            return self.summary()
+        else:
+            return self.summary().encode(errors='replace')
 
     def __unicode__(self):
         return self.summary()
 
-    def alter_standard_name(self, new_standard_name):
-        """
-        Alter the standard name and log an info line to say this is happening if the standard name is not empty.
-        Also changes internal name for metadata or the same.
+    @property
+    def standard_name(self):
+        return self._standard_name
 
-        :param new_standard_name:
-        """
-        if self.standard_name is not None \
-                and self.standard_name.strip() is not "" \
-                and self.standard_name != new_standard_name:
-            logging.info("Changing standard name for dataset from '{}' to '{}'"
-                         .format(self.standard_name, new_standard_name))
-        self.standard_name = new_standard_name
+    @standard_name.setter
+    def standard_name(self, standard_name):
+        from iris.std_names import STD_NAMES
+        if standard_name is None or standard_name in STD_NAMES:
+            # If the standard name is actually changing from one to another then log the fact
+            if self.standard_name is not None \
+                    and self.standard_name.strip() is not "" \
+                    and self.standard_name != standard_name:
+                logging.debug("Changing standard name for dataset from '{}' to '{}'".format(self.standard_name,
+                                                                                            standard_name))
+            self._standard_name = standard_name
+        else:
+            raise ValueError('%r is not a valid standard_name' % standard_name)
 
-        if self._name is not None \
-                and self._name.strip() is not "" \
-                and self._name != new_standard_name:
-            logging.info("Changing variable name for dataset from '{}' to '{}'"
-                         .format(self._name, new_standard_name))
-        self._name = new_standard_name
+    @property
+    def units(self):
+        return self._units
+
+    @units.setter
+    def units(self, units):
+        from cf_units import Unit
+        if not isinstance(units, Unit):
+            try:
+                # Try some basic tidying up of unit
+                if isinstance(units, str):
+                    units = units.replace("since:", "since").replace(",", "")
+                units = Unit(units)
+            except ValueError:
+                logging.info("Unable to parse cf-units: {}. Some operations may not be available.".format(units))
+        self._units = units
 
     @staticmethod
     def guess_standard_name(name):
-        standard_name = name
+        standard_name = None
         if name.lower().startswith('lat'):
             standard_name = 'latitude'
         elif name.lower().startswith('lon'):
             standard_name = 'longitude'
         elif name.lower().startswith('alt') or name.lower() == 'height':
             standard_name = 'altitude'
-        elif name.lower().startswith('pres'):
+        elif name.lower().startswith('pres') or name.lower() == 'air_pressure':
             standard_name = 'air_pressure'
         elif name.lower() == 'time':
             standard_name = 'time'
@@ -239,6 +288,41 @@ class LazyData(object):
         """
         pass
 
+    def __eq__(self, other):
+        import numpy as np
+        result = NotImplemented
+
+        if isinstance(other, LazyData):
+            # Check the metadata
+            result = self.metadata == other.metadata
+
+            # Then, if that is OK, check the data
+            if result:
+                result = np.allclose(self.data, other.data)
+
+        return result
+
+    # Must supply __ne__, Python does not defer to __eq__ for negative equality
+    def __ne__(self, other):
+        result = self.__eq__(other)
+        if result is not NotImplemented:
+            result = not result
+        return result
+
+    # Must supply __hash__, Python 3 does not enable it if __eq__ is defined
+    def __hash__(self):
+        return hash(id(self))
+
+    # Maths operator overloads
+    __add__ = cis.maths.add
+    __radd__ = __add__
+    __sub__= cis.maths.subtract
+    __mul__ = cis.maths.multiply
+    __rmul__ = cis.maths.multiply
+    __div__ = cis.maths.divide
+    __truediv__ = cis.maths.divide
+    __pow__ = cis.maths.exponentiate
+
     @data.setter
     def data(self, value):
         self._data = value
@@ -253,17 +337,6 @@ class LazyData(object):
             self._data_flattened = data.ravel()
         return self._data_flattened
 
-    def copy_metadata_from(self, other_data):
-        """
-        Method to copy the metadata from one UngriddedData/Cube object to another
-        """
-        self._coords = other_data.coords()
-        self.metadata = other_data._metadata
-
-        # def __getitem__(self, item): pass
-        # This method could be overridden to provide the ability to ask for slices of data
-        #  e.g. UngridedDataObject[012:32.4:5]
-
     def add_history(self, new_history):
         """Appends to, or creates, the metadata history attribute using the supplied history string.
         The new entry is prefixed with a timestamp.
@@ -295,7 +368,6 @@ class LazyData(object):
         self.attributes.pop(key, None)
 
     def save_data(self, output_file):
-        output_file = utils.add_file_prefix('cis-', output_file)
         logging.info('Saving data to %s' % output_file)
         write_coordinates(self, output_file)
         add_data_to_file(self, output_file)
@@ -321,15 +393,32 @@ class LazyData(object):
 
             try:
                 if standard_time:
-                    range = (str(cis_standard_time_unit.num2date(self.data.min())),
-                             str(cis_standard_time_unit.num2date(self.data.max())))
+                    range = (cis_standard_time_unit.num2date(self.data.min()),
+                             cis_standard_time_unit.num2date(self.data.max()))
                 else:
                     range = (self.data.min(), self.data.max())
             except ValueError as e:
                 # If we can't set a range for some reason then just leave it blank
                 range = ()
 
-        self.metadata.range = str(range)
+        self.metadata.range = range
+
+    def convert_units(self, new_units):
+        """
+        Convert units of LazyData object to new_units in place
+
+        :param LazyData ug_data:
+        :param cf_units.Unit or str new_units:
+        :raises ValueError if new_units can't be converted to standard units, or units are incompatible
+        """
+        from cf_units import Unit
+        if not isinstance(new_units, Unit):
+            new_units = Unit(new_units)
+        if not isinstance(self.units, Unit):
+            # If our units aren't cf_units then they can't be...
+            raise ValueError("Unable to convert non-standard LazyData units: {}".format(self.units))
+        self.units.convert(self.data, new_units, inplace=True)
+        self.units = new_units
 
 
 class UngriddedData(LazyData, CommonData):
@@ -385,6 +474,8 @@ class UngriddedData(LazyData, CommonData):
                 combined_mask |= numpy.ma.getmaskarray(coord.data).flatten()
                 if coord.data.dtype != 'object':
                     combined_mask |= numpy.isnan(coord.data).flatten()
+                coord.update_shape()
+                coord.update_range()
             if combined_mask.any():
                 n_points = numpy.count_nonzero(combined_mask)
                 logging.warning(
@@ -435,18 +526,42 @@ class UngriddedData(LazyData, CommonData):
             ug_data.add_history(history)
         return ug_data
 
-    def copy(self):
+    def __getitem__(self, keys):
+        """
+        Return a COPY of the data with the given slice. We copy to emulate the Iris Cube behaviour
+        """
+        from copy import deepcopy
+        # Create a copy of the slice of each of the coords
+        new_coords = []
+        for c in self.coords():
+            new_coords.append(c[keys])
+        # The data is just a new LazyData objects with the sliced data. Note this is a slice of the whole (concatenated)
+        #  data, and will lead to post-processing before slicing.
+        # TODO: We could be cleverer and figure out the right slice across the various data managers to only read the
+        #  right data from disk.
+        return UngriddedData(data=self.data[keys].copy(), metadata=deepcopy(self.metadata), coords=new_coords)
+
+    def copy(self, data=None):
         """
         Create a copy of this UngriddedData object with new data and coordinates
         so that that they can be modified without held references being affected.
         Will call any lazy loading methods in the data and coordinates
 
+        :param ndarray data: Replace the data of the ungridded data copy with provided data
+
         :return: Copied UngriddedData object
         """
-        data = numpy.ma.copy(self.data)  # This will load the data if lazy load
+        data = data if data is not None else numpy.ma.copy(self.data)  # This will load the data if lazy load
         coords = self.coords().copy()
         return UngriddedData(data=data, metadata=self.metadata, coords=coords)
 
+    @property
+    def size(self):
+        return self.data.size
+
+    def count(self):
+        return self.data.count() if hasattr(self.data, 'count') else self.data.size
+
     @property
     def history(self):
         return self.metadata.history
@@ -500,19 +615,20 @@ class UngriddedData(LazyData, CommonData):
 
         return df
 
-    def coords(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, dim_coords=True):
+    def coords(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, var_name=None,
+               dim_coords=True):
         """
         :return: A list of coordinates in this UngriddedData object fitting the given criteria
         """
         self._post_process()
-        return self._coords.get_coords(name_or_coord, standard_name, long_name, attributes, axis)
+        return self._coords.get_coords(name_or_coord, standard_name, long_name, attributes, axis, var_name)
 
-    def coord(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None):
+    def coord(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, var_name=None):
         """
         :raise: CoordinateNotFoundError
         :return: A single coord given the same arguments as :meth:`coords`.
         """
-        return self.coords().get_coord(name_or_coord, standard_name, long_name, attributes, axis)
+        return self.coords().get_coord(name_or_coord, standard_name, long_name, attributes, axis, var_name)
 
     def get_coordinates_points(self):
         """Returns a HyperPointView of the coordinates of points.
@@ -585,31 +701,116 @@ class UngriddedData(LazyData, CommonData):
 
         return cls(values, Metadata(), coords)
 
-    def summary(self):
+    def summary(self, shorten=False):
         """
         Unicode summary of the UngriddedData with metadata of itself and its coordinates
         """
-        summary = u'Ungridded data: {name} / ({units}) \n'.format(name=self.name(), units=self.units)
-        summary += u'     Shape = {}\n'.format(self.data.shape) + '\n'
-        summary += u'     Total number of points = {}\n'.format(len(self.get_all_points()))
-        summary += u'     Number of non-masked points = {}\n'.format(len(self.get_non_masked_points()))
+        summary = 'Ungridded data: {name} / ({units}) \n'.format(name=self.name(), units=self.units)
+        if shorten:
+            return summary
 
-        summary += unicode(self.metadata)
+        summary += '     Shape = {}\n'.format(self.data.shape) + '\n'
+        summary += '     Total number of points = {}\n'.format(self.size)
+        summary += '     Number of non-masked points = {}\n'.format(self.count())
 
-        summary += u'     Coordinates: \n'
+        summary += str(self.metadata)
+
+        summary += '     Coordinates: \n'
         for c in self.coords():
-            summary += u'{pad:{width}}{name}\n'.format(pad=' ', width=7, name=c.name())
+            summary += '{pad:{width}}{name}\n'.format(pad=' ', width=7, name=c.name())
             c.update_range()
             summary += c.metadata.summary(offset=10)
 
         return summary
 
+    def __repr__(self):
+        return "<cis 'UngriddedData' of %s>" % self.summary(shorten=True)
+
     def __str__(self):
-        return self.summary().encode(errors='replace')
+        # six has a decorator for this bit, but it doesn't do errors='replace'.
+        if six.PY3:
+            return self.summary()
+        else:
+            return self.summary().encode(errors='replace')
 
     def __unicode__(self):
         return self.summary()
 
+    def set_longitude_range(self, range_start):
+        """
+        Rotates the longitude coordinate array and changes its values by
+        360 as necessary to force the values to be within a 360 range starting
+        at the specified value.
+        :param range_start: starting value of required longitude range
+        """
+        from cis.utils import fix_longitude_range
+        self.coord(standard_name='longitude').data = fix_longitude_range(self.lon.points, range_start)
+
+    def subset(self, **kwargs):
+        """
+        Subset the CommonData object based on the specified constraints
+        :param kwargs:
+        :return:
+        """
+        from cis.subsetting.subset import subset, UngriddedSubsetConstraint
+        return subset(self, UngriddedSubsetConstraint, **kwargs)
+
+    def aggregate(self, how=None, **kwargs):
+        """
+        Aggregate the UngriddedData object based on the specified grids. The grid is defined by passing keyword
+        arguments for each dimension, each argument must be a slice, or have three entries (a maximum, a minimum and a
+        gridstep). The default aggregation method ('moments') returns the mean, standard deviation and number of points
+         as separate GriddedData objects.
+
+        Datetime objects can be used to specify upper and lower datetime limits, or a
+        single PartialDateTime object can be used to specify a datetime range. The gridstep can be specified as a
+        DateTimeDelta object.
+
+        The keyword keys are used to find the relevant coordinate, they are looked for in order of name, standard_name,
+        axis and var_name.
+
+        For example:
+            data.aggregate(x=[-180, 180, 360], y=slice(-90, 90, 10))
+
+        or:
+            data.aggregate(how='mean', t=[PartialDateTime(2008,9), timedelta(days=1))
+
+        :param str how: The kernel to use in the aggregation (moments, mean, min, etc...). Default is moments
+        :param kwargs: The grid specifications for each coordinate dimension
+        :return GriddedData:
+        """
+        agg = _aggregate_ungridded(self, how, **kwargs)
+        # Return the single item if there's only one (this depends on the kernel used)
+        if len(agg) == 1:
+            agg = agg[0]
+        return agg
+
+    def sampled_from(self, data, how='', kernel=None, missing_data_for_missing_sample=True, fill_value=None,
+                     var_name='', var_long_name='', var_units='', **kwargs):
+        """
+        Collocate the CommonData object with another CommonData object using the specified collocator and kernel
+
+        :param CommonData or CommonDataList data: The data to resample
+        :param str how: Collocation method (e.g. lin, nn, bin or box)
+        :param str or cis.collocation.col_framework.Kernel kernel:
+        :param bool missing_data_for_missing_sample: Should missing values in sample data be ignored for collocation?
+        :param float fill_value: Value to use for missing data
+        :param str var_name: The output variable name
+        :param str var_long_name: The output variable's long name
+        :param str var_units: The output variable's units
+        :return CommonData: The collocated dataset
+        """
+        return _ungridded_sampled_from(self, data, how=how, kernel=kernel,
+                                       missing_data_for_missing_sample=missing_data_for_missing_sample,
+                                       fill_value=fill_value, var_name=var_name, var_long_name=var_long_name,
+                                       var_units=var_units, **kwargs)
+
+    def _get_default_plot_type(self, lat_lon=False):
+        if lat_lon:
+            return 'scatter2d'
+        else:
+            return 'line'
+
 
 class UngriddedCoordinates(CommonData):
     """
@@ -633,8 +834,6 @@ class UngriddedCoordinates(CommonData):
         else:
             raise ValueError("Invalid Coords type")
         self._post_process()
-        all_coords = self._coords.find_standard_coords()
-        self.coords_flattened = [(c.data_flattened if c is not None else None) for c in all_coords]
 
     def _post_process(self):
         """
@@ -657,10 +856,26 @@ class UngriddedCoordinates(CommonData):
                 coord.update_shape()
                 coord.update_range()
 
+    @property
+    def coords_flattened(self):
+        all_coords = self.coords().find_standard_coords()
+        return [(c.data_flattened if c is not None else None) for c in all_coords]
+
     @property
     def history(self):
         return "UngriddedCoordinates have no history"
 
+    @property
+    def size(self):
+        if len(self._coords) > 1:
+            return self._coords[0].data.size
+        else:
+            return 0
+
+    def count(self):
+        # There can be no masked coordinate points
+        return self.size
+
     @property
     def x(self):
         return self.coord(axis='X')
@@ -681,6 +896,10 @@ class UngriddedCoordinates(CommonData):
     def time(self):
         return self.coord(standard_name='time')
 
+    @property
+    def var_name(self):
+        return ''
+
     def hyper_point(self, index):
         """
         :param index: The index in the array to find the point for
@@ -703,19 +922,20 @@ class UngriddedCoordinates(CommonData):
         """
         return _coords_as_data_frame(self._coords)
 
-    def coords(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, dim_coords=True):
+    def coords(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, var_name=None,
+               dim_coords=True):
         """
         :return: A list of coordinates in this UngriddedData object fitting the given criteria
         """
-        return self._coords.get_coords(name_or_coord, standard_name, long_name, attributes, axis)
+        return self._coords.get_coords(name_or_coord, standard_name, long_name, attributes, axis, var_name)
 
-    def coord(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None):
+    def coord(self, name_or_coord=None, standard_name=None, long_name=None, attributes=None, axis=None, var_name=None):
         """
         :raise: CoordinateNotFoundError
         :return: A single coord given the same arguments as :meth:`coords`.
 
         """
-        return self._coords.get_coord(name_or_coord, standard_name, long_name, attributes, axis)
+        return self._coords.get_coord(name_or_coord, standard_name, long_name, attributes, axis, var_name)
 
     def get_coordinates_points(self):
         return UngriddedHyperPointView(self.coords_flattened, None)
@@ -740,6 +960,51 @@ class UngriddedCoordinates(CommonData):
         """
         return False
 
+    def set_longitude_range(self, range_start):
+        """
+        Rotates the longitude coordinate array and changes its values by
+        360 as necessary to force the values to be within a 360 range starting
+        at the specified value.
+        :param range_start: starting value of required longitude range
+        """
+        from cis.utils import fix_longitude_range
+        self.coord(standard_name='longitude').data = fix_longitude_range(self.lon.points, range_start)
+
+    def subset(self, **kwargs):
+        raise NotImplementedError("Subset is not available for UngriddedCoordinates objects")
+
+    def collocated_onto(self, sample, how='', kernel=None, **kwargs):
+        raise NotImplementedError("UngriddedCoordinates objects cannot be used as sources of data for collocation.")
+
+    def sampled_from(self, data, how='', kernel=None, missing_data_for_missing_sample=False, fill_value=None,
+                     var_name='', var_long_name='', var_units='', **kwargs):
+        """
+        Collocate the CommonData object with another CommonData object using the specified collocator and kernel
+
+        Note - that the default value for missing_data_for_missing_sample is different in this implementation as
+        compared to the UngriddedData implementation.
+
+        :param CommonData or CommonDataList data: The data to resample
+        :param str how: Collocation method (e.g. lin, nn, bin or box)
+        :param str or cis.collocation.col_framework.Kernel kernel:
+        :param bool missing_data_for_missing_sample: Should missing values in sample data be ignored for collocation?
+        :param float fill_value: Value to use for missing data
+        :param str var_name: The output variable name
+        :param str var_long_name: The output variable's long name
+        :param str var_units: The output variable's units
+        :return CommonData: The collocated dataset
+        """
+        return _ungridded_sampled_from(self, data, how=how, kernel=kernel,
+                                       missing_data_for_missing_sample=missing_data_for_missing_sample,
+                                       fill_value=fill_value, var_name=var_name, var_long_name=var_long_name,
+                                       var_units=var_units, **kwargs)
+
+    def _get_default_plot_type(self, lat_lon=False):
+        raise NotImplementedError("UngriddedCoordinates have no default plot type")
+
+    def var_name(self):
+        raise NotImplementedError("UngriddedCoordinates have no var name")
+
 
 class UngriddedDataList(CommonDataList):
     """
@@ -747,7 +1012,7 @@ class UngriddedDataList(CommonDataList):
     """
 
     def __str__(self):
-        "<UngriddedDataList: %s>" % super(UngriddedDataList, self).__str__()
+        return "UngriddedDataList: \n%s" % super(UngriddedDataList, self).__str__()
 
     @property
     def is_gridded(self):
@@ -762,7 +1027,6 @@ class UngriddedDataList(CommonDataList):
         :param output_file: output filename
         :return:
         """
-        output_file = utils.add_file_prefix('cis-', output_file)
         logging.info('Saving data to %s' % output_file)
         # Should only write coordinates out once
         write_coordinates(self[0], output_file)
@@ -832,6 +1096,36 @@ class UngriddedDataList(CommonDataList):
 
         return df
 
+    def subset(self, **kwargs):
+        from cis.subsetting.subset import subset, UngriddedSubsetConstraint
+        return subset(self, UngriddedSubsetConstraint, **kwargs)
+
+    def aggregate(self, how='', **kwargs):
+        """
+        Aggregate the UngriddedDataList object based on the specified grids. The grid is defined by passing keyword
+        arguments for each dimension, each argument must be a slice, or have three entries (a maximum, a minimum and a
+        gridstep). The default aggregation method ('moments') returns the mean, standard deviation and number of points
+         as separate GriddedData objects (for each UngriddedData object in the list).
+
+        Datetime objects can be used to specify upper and lower datetime limits, or a
+        single PartialDateTime object can be used to specify a datetime range. The gridstep can be specified as a
+        DateTimeDelta object.
+
+        The keyword keys are used to find the relevant coordinate, they are looked for in order of name, standard_name,
+        axis and var_name.
+
+        For example:
+            data.aggregate(x=[-180, 180, 360], y=slice(-90, 90, 10))
+
+        or:
+            data.aggregate(how='mean', t=[PartialDateTime(2008,9), timedelta(days=1))
+
+        :param str how: The kernel to use in the aggregation (moments, mean, min, etc...)
+        :param kwargs: The grid specifications for each coordinate dimension
+        :return GriddedDataList:
+        """
+        return _aggregate_ungridded(self, how, **kwargs)
+
 
 def _coords_as_data_frame(coord_list, copy=True):
     """
@@ -842,6 +1136,7 @@ def _coords_as_data_frame(coord_list, copy=True):
     """
     import pandas as pd
     from cis.time_util import cis_standard_time_unit
+    from cf_units import Unit
 
     columns = {}
     time = None
@@ -854,8 +1149,10 @@ def _coords_as_data_frame(coord_list, copy=True):
             data = _to_flat_ndarray(coord.data, True)
 
         if coord.standard_name == 'time':
-            if coord.units.lower() == 'datetime object':
+            if str(coord.units).lower() == 'datetime object':
                 time = data
+            elif isinstance(coord.units, Unit):
+                time = coord.units.num2date(data)
             else:
                 time = cis_standard_time_unit.num2date(data)
         else:
@@ -877,10 +1174,116 @@ def _to_flat_ndarray(data, copy=True):
     if isinstance(data, np.ma.MaskedArray):
         if not copy:
             raise ValueError("Masked arrays must always be copied.")
-        ndarr = data.astype('f').filled(np.NaN).flatten()
+        # We need to cast the array to a float so that we can fill the array with NaNs for Pandas (which would do the
+        #  same trick itself anyway)
+        ndarr = data.astype(np.float64).filled(np.NaN).flatten()
     elif copy:
         ndarr = data.flatten()
     else:
         ndarr = data.ravel()
 
-    return ndarr
\ No newline at end of file
+    return ndarr
+
+
+def _ungridded_sampled_from(sample, data, how='', kernel=None, missing_data_for_missing_sample=True, fill_value=None,
+                            var_name='', var_long_name='', var_units='', **kwargs):
+    """
+    Collocate the CommonData object with another CommonData object using the specified collocator and kernel
+
+    :param CommonData or CommonDataList data: The data to resample
+    :param str how: Collocation method (e.g. lin, nn, bin or box)
+    :param str or cis.collocation.col_framework.Kernel kernel:
+    :param bool missing_data_for_missing_sample: Should missing values in sample data be ignored for collocation?
+    :param float fill_value: Value to use for missing data
+    :param str var_name: The output variable name
+    :param str var_long_name: The output variable's long name
+    :param str var_units: The output variable's units
+    :return CommonData: The collocated dataset
+    """
+    from cis.collocation import col_implementations as ci
+    from cis.data_io.gridded_data import GriddedData, GriddedDataList
+    from cis.collocation.col import collocate, get_kernel
+
+    if isinstance(data, UngriddedData) or isinstance(data, UngriddedDataList):
+        col = ci.GeneralUngriddedCollocator(fill_value=fill_value, var_name=var_name, var_long_name=var_long_name,
+                                            var_units=var_units,
+                                            missing_data_for_missing_sample=missing_data_for_missing_sample)
+
+        # Box is the default, and only option for ungridded -> ungridded collocation
+        if how not in ['', 'box']:
+            raise ValueError("Invalid method specified for ungridded -> ungridded collocation: " + how)
+        con = ci.SepConstraintKdtree(**kwargs)
+        # We can have any kernel, default to moments
+        kernel = get_kernel(kernel)
+    elif isinstance(data, GriddedData) or isinstance(data, GriddedDataList):
+        col = ci.GriddedUngriddedCollocator(fill_value=fill_value, var_name=var_name, var_long_name=var_long_name,
+                                            var_units=var_units,
+                                            missing_data_for_missing_sample=missing_data_for_missing_sample)
+        con = None
+        kernel = 'lin'
+    else:
+        raise ValueError("Invalid argument, data must be either GriddedData or UngriddedData")
+
+    return collocate(data, sample, col, con, kernel)
+
+
+def _aggregate_ungridded(data, how, **kwargs):
+    """
+    Aggregate an UngriddedData or UngriddedDataList based on the specified grids
+    :param UngriddedData or UngriddedDataList data: The data object to aggregate
+    :param cis.collocation.col_framework.Kernel kernel: The kernel to use in the aggregation
+    :param kwargs: The grid specifications for each coordinate dimension
+    :return:
+    """
+    from cis.aggregation.ungridded_aggregator import UngriddedAggregator
+    from cis.collocation.col import get_kernel
+    from cis.time_util import PartialDateTime
+    from datetime import datetime, timedelta
+    from cis import __version__
+
+    kernel = get_kernel(how)
+    grid_spec = {}
+    for dim_name, grid in kwargs.items():
+        c = data._get_coord(dim_name)
+        if all(hasattr(grid, att) for att in ('start', 'stop', 'step')):
+            g = grid
+        elif len(grid) == 2 and isinstance(grid[0], PartialDateTime):
+            g = slice(grid[0].min(), grid[0].max(), grid[1])
+        elif len(grid) == 3:
+            g = slice(grid[0], grid[1], grid[2])
+        else:
+            raise ValueError("Invalid subset arguments: {}".format(grid))
+
+        # Fill in defaults
+        grid_start = g.start if g.start is not None else c.points.min()
+        if isinstance(grid_start, datetime):
+            grid_start = c.units.date2num(grid_start)
+
+        grid_end = g.stop if g.stop is not None else c.points.max()
+        if isinstance(grid_end, datetime):
+            grid_end = c.units.date2num(grid_end)
+
+        if g.step is None:
+            raise ValueError("Grid step must not be None")
+        else:
+            grid_step = g.step
+
+        if isinstance(grid_step, timedelta):
+            # Standard time is days since, so turn this into a fractional number of days
+            grid_step = grid_step.total_seconds() / (24*60*60)
+
+        grid_spec[c.name()] = slice(grid_start, grid_end, grid_step)
+
+    # We have to make the history before doing the aggregation as the grid dims get popped-off during the operation
+    history = "Aggregated using CIS version " + __version__ + \
+              "\n variables: " + str(getattr(data, "var_name", "Unknown")) + \
+              "\n from files: " + str(getattr(data, "filenames", "Unknown")) + \
+              "\n using new grid: " + str(grid_spec) + \
+              "\n with kernel: " + str(kernel) + "."
+
+    aggregator = UngriddedAggregator(grid_spec)
+    data = aggregator.aggregate(data, kernel)
+
+    data.add_history(history)
+
+    return data
