@@ -10,19 +10,11 @@ from cis.test.integration_test_data import *
 from cis.test.utils_for_testing import *
 from cis.parse import parse_args
 
-try:
-    import pyhdf
-except ImportError:
-    # Disable all these tests if pandas is not installed.
-    pyhdf = None
-
-skip_pyhdf = unittest.skipIf(pyhdf is None, 'Test(s) require "pandas", which is not available.')
-
 
 class BaseAggregationTest(BaseIntegrationTest):
     def check_grid_aggregation(self, lat_start, lat_end, lat_delta, lon_start, lon_end, lon_delta,
                                lat_name='lat', lon_name='lon'):
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         expected_lat_bnds = np.array([[y, y + lat_delta] for y in np.arange(lat_start, lat_end, lat_delta)])
         expected_lon_bnds = np.array([[x, x + lon_delta] for x in np.arange(lon_start, lon_end, lon_delta)])
         lat_bnds = self.ds.variables[lat_name + '_bnds']
@@ -41,7 +33,7 @@ class BaseAggregationTest(BaseIntegrationTest):
         self.ds.close()
 
     def check_temporal_aggregation(self, time_start, time_end, time_delta, time_name='time'):
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         # Convert from time to days after..
 
         def convert_to_days_since_cis_epoch(date_time):
@@ -52,8 +44,7 @@ class BaseAggregationTest(BaseIntegrationTest):
         time_end = convert_to_days_since_cis_epoch(time_end)
         time_delta = time_delta.total_seconds() / dt.timedelta(days=1).total_seconds()
 
-        expected_time_bnds = np.array([[t, t + time_delta] for t in np.arange(time_start, time_end, time_delta)
-                                       if t + time_delta <= time_end * (1 + 1e-13)])
+        expected_time_bnds = np.array([[t, t + time_delta] for t in np.arange(time_start, time_end, time_delta)])
         time_bnds = self.ds.variables[time_name + '_bnds']
         assert_that(time_bnds.shape == expected_time_bnds.shape)
         assert_that(np.allclose(time_bnds[:], expected_time_bnds))
@@ -61,13 +52,13 @@ class BaseAggregationTest(BaseIntegrationTest):
 
     def do_spatial_aggregate(self, variable, filename, lat_start, lat_end, lat_delta, lon_start, lon_end, lon_delta):
         grid = 'x=[%s,%s,%s],y=[%s,%s,%s]' % (lon_start, lon_end, lon_delta, lat_start, lat_end, lat_delta)
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename) + ':kernel=mean', grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
 
     def do_temporal_aggregate(self, variable, filename, t_start, t_end, str_delta):
         grid = 't=[%s,%s,%s]' % (t_start.isoformat(), t_end.isoformat(), str_delta)
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename) + ':kernel=mean', grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
 
@@ -80,7 +71,6 @@ class TestAggregation(BaseAggregationTest):
 
     def test_aggregation_over_latlon(self):
         import numpy.ma as ma
-        from cis import read_data_list
         # Takes 20s
         variable = 'AOD550,AOD870'
         filename = valid_aerosol_cci_filename
@@ -88,27 +78,27 @@ class TestAggregation(BaseAggregationTest):
         lon_start, lon_end, lon_delta = -20, 140, 10  # 16
         self.do_spatial_aggregate(variable, filename, lat_start, lat_end, lat_delta, lon_start, lon_end, lon_delta)
         self.check_grid_aggregation(lat_start, lat_end, lat_delta, lon_start, lon_end, lon_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
         # Test some specific values: these are previous outputs from this aggregate command which have been compared
         # against the original data and found to 'look about right' and therefore used as a baseline. If these values
         # change we should consider being concerned.
         i = float('inf')
         arr_550 = np.array([[[0.1096153093624289, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [0.03419682030959262, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [0.06063271913586593, 0.08715646206228822, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
+                             [0.405634596128, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
+                             [0.175624571614, 0.152486790551, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [0.09970282124016773, 0.1629985723514454, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [0.19553465147813162, 0.40563457332879743, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
+                             [0.19553465147813162, 0.405634596128, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, 0.7052307901349156, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, 0.5859629385860146, 0.4436802918665714, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, 0.29588747474573723, 0.2914036842614198, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, 0.13670555069561927, 0.1756245641523532, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, i, 0.1524867860807313, 0.15664356061755572, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [i, i, i, 0.3850824283435941, 0.929232015972957, i, i, i, i, i, i, i, i, i, i, i],
+                             [i, i, i, 0.1415671800312243, 0.8644281417604477, i, i, i, i, i, i, i, i, i, i, i],
                              [i, i, i, i, 0.18689890454212824, i, i, i, i, i, i, i, i, i, i, 0.17285842509710625]]])
         arr_870 = np.array([[[0.0869540874214068, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [0.0184880101156111, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
-                             [0.0363671136111385, 0.0521519258756329, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
+                             [0.239833246086, i, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
+                             [0.106763551248, 0.0872576713562, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [0.0626557093240659, 0.0976959701925822, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [0.110700003802776, 0.239833255113166, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
                              [i, 0.639897634027878, i, i, i, i, i, i, i, i, i, i, i, i, i, i],
@@ -120,13 +110,14 @@ class TestAggregation(BaseAggregationTest):
                              [i, i, i, i, 0.127948367761241, i, i, i, i, i, i, i, i, i, i, 0.0958142693422429]]])
         arr_550 = ma.masked_invalid(arr_550)
         arr_870 = ma.masked_invalid(arr_870)
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         data_550 = self.ds.variables['AOD550']
         assert_arrays_almost_equal(data_550[:], arr_550.reshape((16,12,1)))
         data_870 = self.ds.variables['AOD870']
         assert_arrays_almost_equal(data_870[:], arr_870.reshape((16,12,1)))
 
     def test_aggregation_over_time(self):
+        import numpy.ma as ma
         # Takes 14s
         variable = 'AOD550,AOD870'
         filename = valid_aerosol_cci_filename
@@ -135,26 +126,28 @@ class TestAggregation(BaseAggregationTest):
         str_delta = 'PT1M'
         self.do_temporal_aggregate(variable, filename, t_start, t_end, str_delta)
         self.check_temporal_aggregation(t_start, t_end, t_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
         # Test some specific values: these are previous outputs from this aggregate command which have been compared
         # against the original data and found to 'look about right' and therefore used as a baseline. If these values
         # change we should consider being concerned.
-        arr_550 = np.array([[[0.265919434976705, 0.291416287011767, 0.185936305122921,
-                              0.199944377828853, 0.15285093049075, 0.216908279904344,
-                              0.319887993484934, 0.331330444179776, 0.425076846698876,
-                              0.691283313656729, 1.09974754591203, 0.762054610928834,
-                              0.414713773233051, 0.229065481573343, 0.565648063149267,
-                              0.372544446844707, 0.200231967265146, 0.126068490624287,
-                              0.100389930256642, 0.0887082928584682]]])
-        arr_870 = np.array([[[0.15076443526022, 0.185600860517914, 0.113000460229053,
-                              0.123627671143187, 0.0904176585404653, 0.135286251594717,
-                              0.24707830522551, 0.29575691650184, 0.383941471034688,
-                              0.62935187193469, 0.993525493281297, 0.695747778782674,
-                              0.373931448211543, 0.207438293844461, 0.336047132128795,
-                              0.220540801986261, 0.118595280574826, 0.0763243285563936,
-                              0.0623867045505904, 0.0538315528589818]]])
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        i = float('inf')
+        arr_550 = np.array( [[[0.2724732138893821, 0.2845287322998047, 0.18888297843565602,
+                               0.1977633680318641, 0.1528509303068309, 0.21690222715974708,
+                               0.3218141342953317, 0.3296216605627661, 0.42861915269278755,
+                               0.6922391289425149, 1.1032210622605763, 0.7501978423274019,
+                               0.4114444071076453, i, 0.5656480511415352, 0.3725444489875726,
+                               0.20023197438583437, 0.12606849266025288, 0.10038993358612061,
+                               0.08870828946431478]]])
+        arr_870 = np.array([[[0.15527870871803978, 0.177825194138747, 0.11566017769478462,
+                               0.12211483395949896, 0.09108650039336486, 0.139907898276485,
+                               0.24998173519681813, 0.29386406702711093, 0.38747846944250536,
+                               0.6303785410104443, 0.999659818761489, 0.6851485338292652,
+                               0.37053351032777904, i, 0.336047126251517, 0.22054079781591365,
+                               0.11859528582197681, 0.07632432809566862, 0.062386703491210935,
+                               0.053831556108262804]]])
+        arr_550 = ma.masked_invalid(arr_550)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         data_550 = self.ds.variables['AOD550']
         assert_arrays_almost_equal(data_550[:], arr_550, 1.0e-2)
         data_870 = self.ds.variables['AOD870']
@@ -164,26 +157,26 @@ class TestAggregation(BaseAggregationTest):
         # JASCIS-281
         variable = 'AOT_440'
         filename = another_valid_aeronet_filename
-        t_start, t_end = dt.datetime(1999, 01, 01), dt.datetime(1999, 12, 29)
+        t_start, t_end = dt.datetime(1999, 0o1, 0o1), dt.datetime(1999, 12, 29)
         t_delta = dt.timedelta(hours=6)
         str_delta = 'PT6H'
         self.do_temporal_aggregate(variable, filename, t_start, t_end, str_delta)
         self.check_temporal_aggregation(t_start, t_end, t_delta, 'DateTime')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
         # Read the aggregated data
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         aot_440 = self.ds.variables['AOT_440'][:]
 
         # Clean up the old aggregation
         self.ds.close()
-        os.remove(self.GRIDDED_OUTPUT_FILENAME)
+        os.remove(self.OUTPUT_FILENAME)
 
         # Now redo the aggregation, but for all AOT variables
         self.do_temporal_aggregate('AOT*', filename, t_start, t_end, str_delta)
 
         # Read the new data in
-        self.ds = Dataset(self.GRIDDED_OUTPUT_FILENAME)
+        self.ds = Dataset(self.OUTPUT_FILENAME)
         aot_440_multi_var = self.ds.variables['AOT_440'][:]
 
         # And check they are the same...
@@ -206,7 +199,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         lat_min, lat_max, lat_delta = -90, 90, 30
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_Cloud_CCI_with_dimension_vars(self):
         variable = 'time,solar_zenith_view_no1'
@@ -215,7 +208,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         lat_min, lat_max, lat_delta = -6, 6, 1
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, ['aggregated_time', 'solar_zenith_view_no1'])
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, ['aggregated_time', 'solar_zenith_view_no1'])
 
     def test_aggregate_Cloud_CCI(self):
         variable = 'satellite_zenith_view_no1,solar_zenith_view_no1'
@@ -224,7 +217,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         lat_min, lat_max, lat_delta = -6, 6, 1
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_Cloud_CCI_for_comparison_with_collocation(self):
         """
@@ -235,23 +228,23 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         variables = ','.join([valid_cloud_cci_variable, valid_cloud_cci_8_bit_variable])
         filename = valid_cloud_cci_filename
         grid = 'x=[0, 358.125, 1.875],y=[-90, 90, 1.25],t=[2007-06-01,2007-06-30,PT3H]'
-        arguments = ['aggregate', variables + ':' + filename + ':kernel=mean', grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variables + ':' + escape_colons(filename) + ':kernel=mean', grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
 
         # This check can't deal with the combined temporal and spatial aggregation so skip it
         #self.check_grid_aggregation(0, 358.125, 1.875, -90, 90, 1.25)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variables.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variables.split(','))
 
     def test_aggregate_NCAR_RAF(self):
         # Takes 513s
-        variable = '*'
+        variable = valid_NCAR_NetCDF_RAF_variable
         filename = valid_NCAR_NetCDF_RAF_filename
         lon_min, lon_max, lon_delta = -160, -157, 1
         lat_min, lat_max, lat_delta = 30, 50, 5
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
-                                    lat_name='latitude', lon_name='longitude')
+                                    lat_name='LATC', lon_name='LONC')
 
     def test_aggregate_GASSP(self):
         variable = '*'
@@ -260,7 +253,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         lat_min, lat_max, lat_delta = 30, 31, 0.1
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
-                                    lat_name='latitude', lon_name='longitude')
+                                    lat_name='GpsLat', lon_name='GpsLon')
 
     def test_aggregate_GASSP2(self):
         # see issue JASCIS-144
@@ -270,7 +263,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         lat_min, lat_max, lat_delta = -90, 90, 10
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
-                                    lat_name='latitude', lon_name='longitude')
+                                    lat_name='LAT_500', lon_name='LON_502')
 
     def test_aggregate_Aeronet(self):
         # Takes 50s
@@ -283,13 +276,15 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
                                     lat_name='Latitude', lon_name='Longitude')
 
     def test_aggregate_netCDF_gridded_HadGem(self):
+        # Test aggregating a gridded file, it should work but throw a deprecation
         # Takes 1s
         variable = '*'
         filename = valid_hadgem_filename
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', 'x,y', '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename) + ':kernel=mean', 'x,y', '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, ['od550aer'])
+
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, ['od550aer'])
 
     def test_aggregate_cis_ungridded(self):
         # Takes 1s
@@ -312,22 +307,6 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
                                     lat_name='Latitude', lon_name='Longitude')
 
-    @skip_pyhdf
-    def test_aggregate_MODIS_L3(self):
-        # (All variables takes 23 mins)
-        # Takes 27s
-        variable = '*'  # Would like to run this but it takes up a lot of memory on Jenkins.
-        variable = 'Optical_Depth_Ratio_Small_Land_And_Ocean_Std_Deviation_Mean,Solar_Zenith_Std_Deviation_Mean,' \
-                   'Solar_Azimuth_Std_Deviation_Mean,Optical_Depth_Ratio_Small_Land_And_Ocean_Pixel_Counts,' \
-                   'Optical_Depth_Ratio_Small_Land_QA_Std_Deviation_Mean'
-        filename = valid_modis_l3_filename
-        lon_min, lon_max, lon_delta = -10, 10, 2
-        lat_min, lat_max, lat_delta = 40, 60, 2
-        self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
-        self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
-                                    lat_name='latitude', lon_name='longitude')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
-
     @skip_pyhdf
     def test_aggregate_CloudSatPRECIP(self):
         # Takes 190s
@@ -361,7 +340,7 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         self.do_spatial_aggregate(variable, filename, lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
                                     lat_name='Latitude', lon_name='Longitude')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     @skip_pyhdf
     def test_aggregate_Caliop_L2(self):
@@ -384,15 +363,6 @@ class TestSpatialAggregationByDataProduct(BaseAggregationTest):
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
                                     lat_name='latitude', lon_name='longitude')
 
-    def test_aggregate_cis_gridded(self):
-        # Takes 1s
-        variable = '*'
-        filename = valid_cis_gridded_output_filename
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', 'x,y', '-o', self.OUTPUT_NAME]
-        main_arguments = parse_args(arguments)
-        aggregate_cmd(main_arguments)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, ['TAU_2D_550nm'])
-
 
 class TestTemporalAggregationByDataProduct(BaseAggregationTest):
     """
@@ -417,7 +387,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'P5D'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_Cloud_CCI(self):
         variable = 'solar_zenith_view_no1'
@@ -428,7 +398,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'P5D'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_NCAR_RAF(self):
         # Takes 28s
@@ -439,8 +409,8 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         time_delta = dt.timedelta(minutes=30)
         str_delta = 'PT30M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
-        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Time')
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_NCAR_RAF_with_named_time_variable_standard_name(self):
         # Takes 28s
@@ -452,12 +422,12 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT30M'
 
         grid = 'time=[%s,%s,%s]' % (time_min.isoformat(), time_max.isoformat(), str_delta)
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename) + ':kernel=mean', grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
 
-        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Time')
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_GASSP(self):
         variable = ",".join(valid_GASSP_aeroplane_vars)
@@ -466,8 +436,19 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         time_delta = dt.timedelta(minutes=30)
         str_delta = 'PT30M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
-        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='UTC_mid')
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
+
+    def test_aggregate_GASSP_aux_coord(self):
+        # Takes 1.3s
+        filename = cis_test_files['GASSP_aux_coord'].master_filename
+        variable = cis_test_files['GASSP_aux_coord'].data_variable_name
+        time_min, time_max = dt.datetime(2006, 9, 27, 20, 15), dt.datetime(2006, 9, 27, 22, 45)
+        time_delta = dt.timedelta(minutes=30)
+        str_delta = 'PT30M'
+        self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
+        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='TIME')
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_Aeronet(self):
         # Takes 2s
@@ -478,7 +459,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT6H'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='DateTime')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_Aeronet_multi_var(self):
         # Takes 2s
@@ -490,36 +471,8 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT6H'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='DateTime')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
-        self.check_output_vars_are_different(self.GRIDDED_OUTPUT_FILENAME, variable.split(',')[:5])
-
-    def test_aggregate_netCDF_gridded_HadGem(self):
-        # Takes 1s
-        variable = 'od550aer'
-        filename = valid_hadgem_filename
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', 't', '-o', self.OUTPUT_NAME]
-        main_arguments = parse_args(arguments)
-        aggregate_cmd(main_arguments)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
-
-    def test_netCDF_gridded_hybrid_height(self):
-        # Takes 2s
-        variable = valid_hybrid_height_variable
-        filename = valid_hybrid_height_filename
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', 't,x,y', '-o', self.OUTPUT_NAME]
-        main_arguments = parse_args(arguments)
-        aggregate_cmd(main_arguments)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
-
-    def test_netCDF_gridded_hybrid_height_partial(self):
-        # JASCIS-126
-        # Takes 2s
-        variable = valid_hybrid_height_variable
-        filename = valid_hybrid_height_filename
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=mean', 't', '-o', self.OUTPUT_NAME]
-        main_arguments = parse_args(arguments)
-        aggregate_cmd(main_arguments)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
+        self.check_output_vars_are_different(self.OUTPUT_FILENAME, variable.split(',')[:5])
 
     def test_aggregate_cis_ungridded(self):
         # Takes 2s
@@ -530,7 +483,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT1S'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     @skip_pyhdf
     def test_aggregate_MODIS_L2(self):
@@ -542,21 +495,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT1M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Scan_Start_Time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
-
-    @skip_pyhdf
-    def test_aggregate_MODIS_L3(self):
-        # Takes 8s
-        variable = 'Optical_Depth_Ratio_Small_Land_And_Ocean_Std_Deviation_Mean,Solar_Zenith_Std_Deviation_Mean,' \
-                   'Solar_Azimuth_Std_Deviation_Mean,Optical_Depth_Ratio_Small_Land_And_Ocean_Pixel_Counts,' \
-                   'Optical_Depth_Ratio_Small_Land_QA_Std_Deviation_Mean'
-        filename = valid_modis_l3_filename
-        time_min, time_max = dt.datetime(2010, 1, 13, 0, 0, 1), dt.datetime(2010, 1, 13, 0, 1, 44)
-        time_delta = dt.timedelta(seconds=20)
-        str_delta = 'PT20S'
-        self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
-        self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='DateTime')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     @skip_pyhdf
     def test_aggregate_CloudSatPRECIP_with_dimension_variables(self):
@@ -569,7 +508,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT30M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Profile_time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(',') +
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(',') +
                                              ['aggregated_Profile_time'])
 
     @skip_pyhdf
@@ -581,7 +520,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT30M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Profile_time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, [valid_cloudsat_PRECIP_variable])
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, [valid_cloudsat_PRECIP_variable])
 
     @skip_pyhdf
     def test_aggregate_CloudSatRVOD(self):
@@ -593,7 +532,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT23M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Profile_time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     @unittest.skip("Very resource intensive")
     def test_aggregate_Caliop_L1(self):
@@ -605,7 +544,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT15M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Profile_Time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     @skip_pyhdf
     def test_aggregate_Caliop_L2(self):
@@ -618,7 +557,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'PT15M'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta, time_name='Profile_Time')
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
     def test_aggregate_ASCII(self):
         # Takes 1s
@@ -629,7 +568,7 @@ class TestTemporalAggregationByDataProduct(BaseAggregationTest):
         str_delta = 'P1D'
         self.do_temporal_aggregate(variable, filename, time_min, time_max, str_delta)
         self.check_temporal_aggregation(time_min, time_max, time_delta)
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, variable.split(','))
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, variable.split(','))
 
 
 class TestMomentsKernel(BaseAggregationTest):
@@ -640,24 +579,13 @@ class TestMomentsKernel(BaseAggregationTest):
         lon_min, lon_max, lon_delta = 1, 3, 0.3
         lat_min, lat_max, lat_delta = 41, 42, 0.1
         grid = 'x=[%s,%s,%s],y=[%s,%s,%s]' % (lon_min, lon_max, lon_delta, lat_min, lat_max, lat_delta)
-        arguments = ['aggregate', variable + ':' + filename, grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename), grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
                                     lat_name='latitude', lon_name='longitude')
         expected_vars = ['AOD550', 'AOD550_std_dev', 'AOD550_num_points']
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, expected_vars)
-
-    def test_aggregate_netCDF_gridded_HadGem(self):
-        # Takes 1s
-        variable = 'od550aer'
-        filename = valid_hadgem_filename
-        grid = 'x,y'
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=moments', grid, '-o', self.OUTPUT_NAME]
-        main_arguments = parse_args(arguments)
-        aggregate_cmd(main_arguments)
-        expected_vars = ['od550aer', 'od550aer_std_dev', 'od550aer_num_points']
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, expected_vars)
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, expected_vars)
 
     def test_moments_kernel_aggregate_cis_ungridded(self):
         # Takes 1s
@@ -666,11 +594,11 @@ class TestMomentsKernel(BaseAggregationTest):
         lon_min, lon_max, lon_delta = 1, 3, 0.3
         lat_min, lat_max, lat_delta = 41, 42, 0.1
         grid = 'x=[%s,%s,%s],y=[%s,%s,%s]' % (lon_min, lon_max, lon_delta, lat_min, lat_max, lat_delta)
-        arguments = ['aggregate', variable + ':' + filename + ':kernel=moments', grid, '-o', self.OUTPUT_NAME]
+        arguments = ['aggregate', variable + ':' + escape_colons(filename) + ':kernel=moments', grid, '-o', self.OUTPUT_FILENAME]
         main_arguments = parse_args(arguments)
         aggregate_cmd(main_arguments)
         self.check_grid_aggregation(lat_min, lat_max, lat_delta, lon_min, lon_max, lon_delta,
                                     lat_name='latitude', lon_name='longitude')
         expected_vars = ['AOD870', 'AOD870_std_dev', 'AOD870_num_points',
                          'AOD550', 'AOD550_std_dev', 'AOD550_num_points']
-        self.check_output_contains_variables(self.GRIDDED_OUTPUT_FILENAME, expected_vars)
+        self.check_output_contains_variables(self.OUTPUT_FILENAME, expected_vars)
